@@ -2,14 +2,14 @@
 /**
  * \file agCgi.c
  *
- *  Time-stamp:        "2010-08-06 08:54:16 bkorb"
+ *  Time-stamp:        "2011-01-20 16:24:54 bkorb"
  *
  *  This is a CGI wrapper for AutoGen.  It will take POST-method
  *  name-value pairs and emit AutoGen definitions to a spawned
  *  AutoGen process.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -159,7 +159,8 @@ loadCgi(void)
 static char*
 parseInput(char* pzSrc, int len)
 {
-    tSCC   zDef[] = "Autogen Definitions cgi;\n";
+    static char const zDef[] = "Autogen Definitions cgi;\n";
+
 #   define defLen   (sizeof(zDef) - 1)
     char*  pzRes  = AGALOC((len * 2) + defLen + 1, "CGI Definitions");
 
