@@ -5,7 +5,7 @@
  *  Do all the initialization stuff.  For daemon mode, only
  *  children will return.
  *
- *  Time-stamp:      "2011-02-23 10:59:39 bkorb"
+ *  Time-stamp:      "2011-04-20 15:20:27 bkorb"
  *
  *  This file is part of AutoGen.
  *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
@@ -156,15 +156,15 @@ dep_usage(char const * fmt, ...)
         va_end(ap);
     }
 
-    fprintf(stderr, "invalid make dependency option:  %s", msg);
-    USAGE(EXIT_FAILURE);
+    usage_message("invalid make dependency option:  %s", msg);
+    /* NOTREACHED */
 }
 
 /**
  * Configure dependency option
  */
 LOCAL void
-config_dep(tOptions* pOptions, tOptDesc* pOptDesc)
+config_dep(tOptions * pOptions, tOptDesc * pOptDesc)
 {
     static char const dup_targ[] = "duplicate make target";
 
@@ -181,7 +181,7 @@ config_dep(tOptions* pOptions, tOptDesc* pOptDesc)
 retry:
 
     switch (*popt) {
-    case ' ': case '\t': case '\r': case '\n':
+    case ' ': case TAB: case '\r': case NL:
         while (isspace((int)*(++popt)))  ;
         goto retry;
 
