@@ -2,7 +2,7 @@
 /**
  * \file expOutput.c
  *
- *  Time-stamp:        "2011-02-28 14:58:46 bkorb"
+ *  Time-stamp:        "2011-05-05 11:01:03 bkorb"
  *
  *  This module implements the output file manipulation function
  *
@@ -76,7 +76,7 @@ current_line(FILE * fp)
 
     while (! feof(fp)) {
         int ch = getc(fp);
-        if (ch == '\n')
+        if (ch == NL)
             lnno++;
     }
 
@@ -456,7 +456,6 @@ ag_scm_out_emit_suspended(SCM susp_nm)
 /*=gfunc ag_fprintf
  *
  * what:  format to autogen stream
- * general_use:
  *
  * exparg: ag-diversion, AutoGen diversion name or number
  * exparg: format,       formatting string
@@ -791,7 +790,7 @@ ag_scm_out_line(void)
             unsigned char ch = ich;
             if (ich < 0)
                 break;
-            if (ch == (unsigned char)'\n')
+            if (ch == (unsigned char)NL)
                 lineNum++;
         } while (--pos > 0);
         fseek(pCurFp->pFile, svpos, SEEK_SET);
