@@ -2,7 +2,7 @@
 /**
  * \file expPrint.c
  *
- *  Time-stamp:        "2010-07-16 15:17:19 bkorb"
+ *  Time-stamp:        "2011-01-20 16:21:45 bkorb"
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -11,7 +11,7 @@
  *  a core dump :-)
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -70,8 +70,9 @@ safePrintf(char** ppzBuf, char const * pzFmt, void** argV)
     }
 
     {
-        tSCC zBadArgs[] = "Bad args to sprintf";
-        tSCC zBadFmt[]  = "%s ERROR:  %s processing printf format:\n\t%s\n";
+        static char const zBadArgs[] = "Bad args to sprintf";
+        static char const zBadFmt[]  =
+            "%s ERROR:  %s processing printf format:\n\t%s\n";
 
         /*
          *  IF the sprintfv call below is going to address fault,
@@ -128,7 +129,7 @@ run_printf(char const * pzFmt, int len, SCM alist)
     while (len-- > 0) {
         SCM  car = SCM_CAR(alist);
         alist = SCM_CDR(alist);
-        switch (gh_type_e(car)) {
+        switch (ag_scm_type_e(car)) {
         default:
         case GH_TYPE_UNDEFINED:
             *(argp++) = (char*)"???";
@@ -139,7 +140,7 @@ run_printf(char const * pzFmt, int len, SCM alist)
             break;
 
         case GH_TYPE_CHAR:
-            *(char*)(argp++) = gh_scm2char(car);
+            *(char*)(argp++) = AG_SCM_CHAR(car);
             break;
 
         case GH_TYPE_PAIR:
@@ -147,7 +148,7 @@ run_printf(char const * pzFmt, int len, SCM alist)
             break;
 
         case GH_TYPE_NUMBER:
-            *(unsigned long*)(argp++) = gh_scm2ulong(car);
+            *(unsigned long*)(argp++) = AG_SCM_TO_ULONG(car);
             break;
 
         case GH_TYPE_SYMBOL:
@@ -226,7 +227,7 @@ ag_scm_printf(SCM fmt, SCM alist)
     int   list_len = scm_ilength(alist);
     char* pzFmt    = ag_scm2zchars(fmt, zFormat);
 
-    gh_display(run_printf(pzFmt, list_len, alist));
+    AG_SCM_DISPLAY(run_printf(pzFmt, list_len, alist));
     return SCM_UNDEFINED;
 }
 
@@ -270,7 +271,8 @@ ag_scm_fprintf(SCM port, SCM fmt, SCM alist)
 SCM
 ag_scm_hide_email(SCM display, SCM eaddr)
 {
-    tSCC zStrt[]  =
+    static char const zFmt[]   = "&#%d;";
+    static char const zStrt[]  =
         "<script language=\"JavaScript\" type=\"text/javascript\">\n"
         "<!--\n"
         "var one = 'm&#97;';\n"
@@ -278,11 +280,10 @@ ag_scm_hide_email(SCM display, SCM eaddr)
         "document.write('<a href=\"' + one + two );\n"
         "document.write('&#111;:";
 
-    tSCC zEnd[]   = "');\n"
+    static char const zEnd[]   = "');\n"
         "document.write('\" >%s</a>');\n"
         "//-->\n</script>";
 
-    tSCC zFmt[]   = "&#%d;";
     char*  pzDisp = ag_scm2zchars(display, zFormat);
     char*  pzEadr = ag_scm2zchars(eaddr,   zFormat);
     size_t str_size = (strlen(pzEadr) * sizeof(zFmt))
