@@ -4,13 +4,11 @@
  *
  *  This module implements the CASE text function.
  *
- *  Time-stamp:        "2010-07-16 17:25:03 bkorb"
+ *  Time-stamp:        "2011-01-31 12:18:34 bkorb"
  */
-/*=--subblock=exparg=arg_name,arg_desc,arg_optional,arg_list=*/
-
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -39,7 +37,7 @@
 
 #define PTRUP(p) STMTS(if(IS_LOW(*(p))) *(p)=_toupper(*(p));(p)++)
 
-tSCC zBadRe[]  = "Invalid regular expression:  error %d (%s):\n%s";
+static char const zBadRe[] = "Invalid regular expression:  error %d (%s):\n%s";
 
 typedef tSuccess (tSelectProc)(char const * sample, char const * pattern);
 static tSelectProc
@@ -321,7 +319,7 @@ Select_Equivalent(char const * sample, char const * pattern)
 SCM
 ag_scm_string_contains_eqv_p(SCM text, SCM substr)
 {
-    tSCC zSrch[] = "search string";
+    static char const zSrch[] = "search string";
     char* pzSubstr;
     SCM   res;
 
@@ -1068,7 +1066,7 @@ mLoad_Case(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
     /*
      *  Save the global macro loading mode
      */
-    tpLoadProc*    papLP = papLoadProc;
+    tpLoadProc const * papLP = papLoadProc;
 
     /*
      *  IF there is no associated text expression
@@ -1084,7 +1082,7 @@ mLoad_Case(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 
     /*
      *  IF this is the first time here,
-     *  THEN set up the "CASE" mode callout table.
+     *  THEN set up the "CASE" mode callout tables.
      *  It is the standard table, except entries are inserted
      *  for SELECT and ESAC.
      */
@@ -1092,17 +1090,17 @@ mLoad_Case(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
         int i;
 
         /*
-         *  Until there is a selection clause, _any_ other
-         *  macro will be illegal (except comments :)!
+         *  Until there is a selection clause, only comment and select
+         *  macros are allowed.
          */
         for (i=0; i < FUNC_CT; i++)
-            apSelectOnly[i] = &mLoad_Bogus;
+            apSelectOnly[i] = mLoad_Bogus;
 
         memcpy((void*)apCaseLoad, apLoadProc, sizeof( apLoadProc ));
         apSelectOnly[ FTYP_COMMENT] = mLoad_Comment;
         apSelectOnly[ FTYP_SELECT ] = \
-        apCaseLoad[   FTYP_SELECT ] = &mLoad_Select;
-        apCaseLoad[   FTYP_ESAC   ] = &mLoad_Ending;
+        apCaseLoad[   FTYP_SELECT ] = mLoad_Select;
+        apCaseLoad[   FTYP_ESAC   ] = mLoad_Ending;
     }
 
     /*
@@ -1170,12 +1168,12 @@ mLoad_Case(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 static tMacro*
 mLoad_Select(tTemplate * pT, tMacro* pMac, char const ** ppzScan)
 {
-    char const *    pzScan = *ppzScan;  /* text after macro */
-    char*          pzCopy = pT->pNext; /* next text dest   */
-    char const *    pzSrc  = (char*)pMac->ozText; /* macro text */
-    long           srcLen = pMac->res;           /* macro len  */
+    char const *  pzScan = *ppzScan;  /* text after macro */
+    char*         pzCopy = pT->pNext; /* next text dest   */
+    char const *  pzSrc  = (char*)pMac->ozText; /* macro text */
+    long          srcLen = pMac->res;           /* macro len  */
 
-    tSCC zInvSel[] = "Invalid selection clause";
+    static char const zInvSel[] = "Invalid selection clause";
     int  typ       = (int)FTYP_SELECT_COMPARE_FULL;
 
     /*
