@@ -1,13 +1,13 @@
 
-/*
- *  $Id: 68e07b244ee6fed833ec9267d63ef0efb186178d $
+/**
+ *  \file functions.c
  *
- *  Time-stamp:        "2010-02-24 08:42:08 bkorb"
+ *  Time-stamp:        "2011-04-20 14:22:51 bkorb"
  *
  *  This module implements text functions.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -23,8 +23,8 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-tSCC zCantInc[] = "cannot include file";
-tSCC zTrcFmt[] = "%-10s (%2X) in %s at line %d\n";
+static char const zCantInc[] = "cannot include file";
+static char const zTrcFmt[] = "%-10s (%2X) in %s at line %d\n";
 
 /*=macfunc INCLUDE
  *
@@ -44,12 +44,12 @@ tSCC zTrcFmt[] = "%-10s (%2X) in %s at line %d\n";
  *  terminating macro functions.
 =*/
 tMacro*
-mFunc_Include( tTemplate* pT, tMacro* pMac )
+mFunc_Include(tTemplate* pT, tMacro* pMac)
 {
-    tTemplate* pNewTpl;
-    ag_bool    needFree;
-    tCC*       pzFile = evalExpression( &needFree );
-    tMacro*    pM;
+    tTemplate *   pNewTpl;
+    ag_bool       needFree;
+    char const *  pzFile = evalExpression(&needFree);
+    tMacro*       pM;
 
     if (*pzFile != NUL) {
         pNewTpl = loadTemplate(pzFile, pT->pzTplFile);
@@ -60,8 +60,8 @@ mFunc_Include( tTemplate* pT, tMacro* pMac )
         pM = pNewTpl->aMacros + (pNewTpl->macroCt - 1);
         if (pM->funcCode == FTYP_TEXT) {
             char* pz  = pNewTpl->pzTemplText + pM->ozText;
-            char* pzE = pz + strlen( pz );
-            while ((pzE > pz) && isspace( pzE[-1] ))  --pzE;
+            char* pzE = pz + strlen(pz);
+            while ((pzE > pz) && isspace(pzE[-1]))  --pzE;
 
             /*
              *  IF there is no text left, remove the macro entirely
@@ -72,22 +72,22 @@ mFunc_Include( tTemplate* pT, tMacro* pMac )
         }
 
         if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE) {
-            tSCC zTplFmt[] = "Template %s included\n";
-            tSCC zLinFmt[] = "\tfrom %s line %d\n";
-            fprintf( pfTrace, zTplFmt, pNewTpl->pzTplFile );
+            static char const zTplFmt[] = "Template %s included\n";
+            static char const zLinFmt[] = "\tfrom %s line %d\n";
+            fprintf(pfTrace, zTplFmt, pNewTpl->pzTplFile);
             if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
-                fprintf( pfTrace, zLinFmt, pCurTemplate->pzTplFile,
-                         pMac->lineNo );
+                fprintf(pfTrace, zLinFmt, pCurTemplate->pzTplFile,
+                        pMac->lineNo);
         }
 
-        generateBlock( pNewTpl, pNewTpl->aMacros,
-                       pNewTpl->aMacros + pNewTpl->macroCt );
-        unloadTemplate( pNewTpl );
+        generateBlock(pNewTpl, pNewTpl->aMacros,
+                      pNewTpl->aMacros + pNewTpl->macroCt);
+        unloadTemplate(pNewTpl);
         pCurTemplate = pT;
     }
 
     if (needFree)
-        AGFREE( (void*)pzFile );
+        AGFREE((void*)pzFile);
 
     return pMac + 1;
 }
@@ -100,11 +100,11 @@ mFunc_Include( tTemplate* pT, tMacro* pMac )
  *  Regular "expr" macros are their own argument, so there is always one.
  */
 tMacro*
-mLoad_Include( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
+mLoad_Include(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 {
     if ((int)pMac->res == 0)
-        AG_ABEND_IN( pT, pMac, "The INCLUDE macro requires a file name" );
-    return mLoad_Expr( pT, pMac, ppzScan );
+        AG_ABEND_IN(pT, pMac, "The INCLUDE macro requires a file name");
+    return mLoad_Expr(pT, pMac, ppzScan);
 }
 
 
@@ -125,23 +125,23 @@ mLoad_Include( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  *  You may not specify @code{UNKNOWN} explicitly.
 =*/
 tMacro*
-mFunc_Unknown( tTemplate* pT, tMacro* pMac )
+mFunc_Unknown(tTemplate* pT, tMacro* pMac)
 {
-    tTemplate* pInv = findTemplate( pT->pzTemplText + pMac->ozName );
+    tTemplate * pInv = findTemplate(pT->pzTemplText + pMac->ozName);
     if (pInv != NULL) {
         if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
-            fprintf( pfTrace, zTrcFmt, "remapped to 'Invoke'", pMac->funcCode,
-                     pT->pzTplFile, pMac->lineNo );
+            fprintf(pfTrace, zTrcFmt, "remapped to 'Invoke'", pMac->funcCode,
+                    pT->pzTplFile, pMac->lineNo);
         pMac->funcCode    = FTYP_DEFINE;
         pMac->funcPrivate = (void*)pInv;
-        parseMacroArgs( pT, pMac );
-        return mFunc_Define( pT, pMac );
+        parseMacroArgs(pT, pMac);
+        return mFunc_Define(pT, pMac);
     }
 
     if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
-        fprintf( pfTrace, zTrcFmt, "remapped to Expr", pMac->funcCode,
-                 pT->pzTplFile, pMac->lineNo );
-        fprintf( pfTrace, "\tbased on %s\n", pT->pzTemplText + pMac->ozName );
+        fprintf(pfTrace, zTrcFmt, "remapped to Expr", pMac->funcCode,
+                pT->pzTplFile, pMac->lineNo);
+        fprintf(pfTrace, "\tbased on %s\n", pT->pzTemplText + pMac->ozName);
     }
 
     pMac->funcCode = FTYP_EXPR;
@@ -158,12 +158,12 @@ mFunc_Unknown( tTemplate* pT, tMacro* pMac )
 
         case '`':
             pMac->res = EMIT_SHELL;
-            spanQuote( pzExpr );
+            spanQuote(pzExpr);
             break;
 
         case '"':
         case '\'':
-            spanQuote( pzExpr );
+            spanQuote(pzExpr);
             /* FALLTHROUGH */
 
         default:
@@ -171,10 +171,10 @@ mFunc_Unknown( tTemplate* pT, tMacro* pMac )
         }
 
         if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
-            fprintf( pfTrace, "\tcode %lX -- %s\n", pMac->res, pzExpr );
+            fprintf(pfTrace, "\tcode %lX -- %s\n", pMac->res, pzExpr);
     }
 
-    return mFunc_Expr( pT, pMac );
+    return mFunc_Expr(pT, pMac);
 }
 
 
@@ -186,12 +186,15 @@ mFunc_Unknown( tTemplate* pT, tMacro* pMac )
  *  unnamed:
 =*/
 tMacro*
-mFunc_Bogus( tTemplate* pT, tMacro* pMac )
+mFunc_Bogus(tTemplate* pT, tMacro* pMac)
 {
-    tSCC z[] = "%d (%s) is an unknown macro function, or has no handler";
-    char* pz = aprf( z, pMac->funcCode, (pMac->funcCode < FUNC_CT)
-                     ? apzFuncNames[ pMac->funcCode ] : "??" );
-    AG_ABEND_IN( pT, pMac, pz );
+    static char const z[] =
+        "%d (%s) is an unknown macro function, or has no handler";
+
+    char* pz = aprf(z, pMac->funcCode, (pMac->funcCode < FUNC_CT)
+                    ? apzFuncNames[ pMac->funcCode ] : "??");
+
+    AG_ABEND_IN(pT, pMac, pz);
     /* NOTREACHED */
     return pMac;
 }
@@ -204,10 +207,10 @@ mFunc_Bogus( tTemplate* pT, tMacro* pMac )
  *  unnamed:
 =*/
 tMacro*
-mFunc_Text( tTemplate* pT, tMacro* pMac )
+mFunc_Text(tTemplate* pT, tMacro* pMac)
 {
-    fputs( pT->pzTemplText + pMac->ozText, pCurFp->pFile );
-    fflush( pCurFp->pFile );
+    fputs(pT->pzTemplText + pMac->ozText, pCurFp->pFile);
+    fflush(pCurFp->pFile);
     return pMac + 1;
 }
 
@@ -231,9 +234,9 @@ mFunc_Text( tTemplate* pT, tMacro* pMac )
  *    @end example
 =*/
 tMacro*
-mLoad_Comment( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
+mLoad_Comment(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 {
-    memset( (void*)pMac, 0, sizeof( *pMac ));
+    memset((void*)pMac, 0, sizeof(*pMac));
     return pMac;
 }
 
@@ -245,11 +248,11 @@ mLoad_Comment( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  *  This is used as the default load mechanism.
  */
 tMacro*
-mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
+mLoad_Unknown(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 {
-    char*          pzCopy = pT->pNext;
-    char const*    pzSrc;
-    size_t         srcLen = (size_t)pMac->res;         /* macro len  */
+    char *        pzCopy = pT->pNext;
+    char const *  pzSrc;
+    size_t        srcLen = (size_t)pMac->res;         /* macro len  */
 
     if (srcLen <= 0)
         goto return_emtpy_expression;
@@ -262,12 +265,12 @@ mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
          *  Strip off scheme comments
          */
         do  {
-            while (--srcLen, (*++pzSrc != '\n')) {
+            while (--srcLen, (*++pzSrc != NL)) {
                 if (srcLen <= 0)
                     goto return_emtpy_expression;
             }
 
-            while (--srcLen, isspace( *++pzSrc )) {
+            while (--srcLen, isspace(*++pzSrc)) {
                 if (srcLen <= 0)
                     goto return_emtpy_expression;
             }
@@ -290,22 +293,22 @@ mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
          *  Move back the source pointer.  We may have skipped blanks,
          *  so skip over however many first, then back up over the name.
          */
-        while (isspace( pzSrc[-1] )) pzSrc--, srcLen++;
-        remLen  = strlen( pzCopy );
+        while (isspace(pzSrc[-1])) pzSrc--, srcLen++;
+        remLen  = strlen(pzCopy);
         pzSrc  -= remLen;
         srcLen += remLen;
 
         /*
          *  Now copy over the full canonical name.  Check for errors.
          */
-        remLen = canonicalizeName( pzCopy, pzSrc, (int)srcLen );
+        remLen = canonicalizeName(pzCopy, pzSrc, (int)srcLen);
         if (remLen > srcLen)
-            AG_ABEND_IN( pT, pMac, "Invalid definition name" );
+            AG_ABEND_IN(pT, pMac, "Invalid definition name");
 
         pzSrc  += srcLen - remLen;
         srcLen  = remLen;
 
-        pT->pNext = pzCopy + strlen( pzCopy ) + 1;
+        pT->pNext = pzCopy + strlen(pzCopy) + 1;
         if (srcLen <= 0)
             goto return_emtpy_expression;
         break;
@@ -333,29 +336,27 @@ mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 }
 
 
-/*
- *  mLoad_Bogus
- *
+/**
  *  Some functions are known to AutoGen, but invalid out of context.
  *  For example, ELIF, ELSE and ENDIF are all known to AutoGen.
  *  However, the load function pointer for those functions points
  *  here, until an "IF" function is encountered.
  */
 tMacro*
-mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
+mLoad_Bogus(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 {
-    tSCC zUnk[] =
+    static char const zUnk[] =
         "Unknown macro or invalid context in %s line %d:\n\t%s%s";
 
-    tCC* pzSrc = (char const*)pMac->ozText; /* macro text */
-    tCC* pzMac;
+    char const * pzSrc = (char const*)pMac->ozText; /* macro text */
+    char const * pzMac;
 
     char z[ 64 ];
 
     if (pzSrc != NULL) {
         z[0] = ':';
         z[1] = z[2] = ' ';
-        strncpy( z+3, pzSrc, (size_t)60 );
+        strncpy(z+3, pzSrc, (size_t)60);
         z[63] = NUL;
         pzSrc = z;
     }
@@ -370,9 +371,9 @@ mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         pzMac = apzFuncNames[ ix ];
     }
 
-    pzSrc = aprf( zUnk, pT->pzTplFile, pMac->lineNo, pzMac, pzSrc );
+    pzSrc = aprf(zUnk, pT->pzTplFile, pMac->lineNo, pzMac, pzSrc);
 
-    AG_ABEND_IN( pT, pMac, pzSrc );
+    AG_ABEND_IN(pT, pMac, pzSrc);
     /* NOTREACHED */
     return NULL;
 }
