@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Mon Mar  7 16:35:31 PST 2011
+ * Generated Fri May  6 07:07:10 PDT 2011
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -25,7 +25,7 @@ LOCAL void
 initialize(int arg_ct, char** arg_vec);
 
 LOCAL void
-config_dep(tOptions* pOptions, tOptDesc* pOptDesc);
+config_dep(tOptions * pOptions, tOptDesc * pOptDesc);
 
 /*
  *  Extracted from agShell.c
@@ -42,6 +42,9 @@ runShell(char const*  pzCmd);
 LOCAL char *
 aprf(char const * pzFmt, ...);
 
+LOCAL void
+open_trace_file(char ** av, tOptDesc * odsc);
+
 LOCAL void
 doOptions(int arg_ct, char ** arg_vec);
 
@@ -76,9 +79,6 @@ ao_malloc (size_t sz);
 LOCAL void *
 ao_realloc (void *p, size_t sz);
 
-LOCAL void
-ao_free (void *p);
-
 LOCAL char *
 ao_strdup (char const * str);
 
@@ -155,6 +155,12 @@ open_output_file(char const * fname, size_t nmsz, char const * mode, int flags);
 LOCAL SCM
 run_printf(char const * pzFmt, int len, SCM alist);
 
+/*
+ *  Extracted from expString.c
+ */
+LOCAL void
+do_multi_subs(char ** ppzStr, scm_sizet * pStrLen, SCM match, SCM repl);
+
 /*
  *  Extracted from funcDef.c
  */
