@@ -2,7 +2,7 @@
 /**
  * \file numeric.c
  *
- *  Time-stamp:      "2011-03-05 10:31:18 bkorb"
+ *  Time-stamp:      "2011-03-25 16:26:10 bkorb"
  *
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
@@ -46,59 +46,50 @@ optionShowRange(tOptions* pOpts, tOptDesc* pOD, void * rng_table, int rng_ct)
 
     const struct {long const rmin, rmax;} * rng = rng_table;
 
-    char const * pz_indent =
-        (pOpts != OPTPROC_EMIT_USAGE) ? onetab : bullet;
+    char const * pz_indent    = bullet;
 
-    if ((pOpts == OPTPROC_EMIT_USAGE) || (pOpts > OPTPROC_EMIT_LIMIT)) {
-        char const * lie_in_range = zRangeLie;
+    /*
+     * The range is shown only for full usage requests and an error
+     * in this particular option.
+     */
+    if (pOpts != OPTPROC_EMIT_USAGE) {
+        if (pOpts <= OPTPROC_EMIT_LIMIT)
+            return;
+        pz_indent = onetab;
 
-        if (pOpts > OPTPROC_EMIT_LIMIT) {
-            fprintf(option_usage_fp, zRangeErr,
-                    pOpts->pzProgName, pOD->pz_Name, pOD->optArg.argString);
-            fprintf(option_usage_fp, "The %s option:\n", pOD->pz_Name);
-            lie_in_range = zRangeBadLie;
-            pz_indent = "";
-        }
-
-        if (pOD->fOptState & OPTST_SCALED_NUM)
-            fprintf(option_usage_fp, zRangeScaled, pz_indent);
-
-        if (rng_ct > 1) {
-            fprintf(option_usage_fp, lie_in_range, pz_indent);
-            pz_indent =
-                (pOpts != OPTPROC_EMIT_USAGE) ? onetab : deepin;
-
-        } else {
-            fprintf(option_usage_fp, zRangeOnly, pz_indent);
-            pz_indent = onetab + 1; /* empty string */
-        }
-
-        for (;;) {
-            if (rng->rmax == LONG_MIN)
-                fprintf(option_usage_fp, zRangeExact, pz_indent, rng->rmin);
-            else if (rng->rmin == LONG_MIN)
-                fprintf(option_usage_fp, zRangeUpto, pz_indent, rng->rmax);
-            else if (rng->rmax == LONG_MAX)
-                fprintf(option_usage_fp, zRangeAbove, pz_indent, rng->rmin);
-            else
-                fprintf(option_usage_fp, zRange, pz_indent, rng->rmin,
-                        rng->rmax);
-
-            if  (--rng_ct <= 0) {
-                fputc('\n', option_usage_fp);
-                break;
-            }
-            fputs(zRangeOr, option_usage_fp);
-            rng++;
-            pz_indent =
-                (pOpts != OPTPROC_EMIT_USAGE) ? onetab : deepin;
-        }
-
-        if (pOpts > OPTPROC_EMIT_LIMIT)
-            pOpts->pUsageProc(pOpts, EXIT_FAILURE);
+        fprintf(option_usage_fp, zRangeErr, pOpts->pzProgName,
+                pOD->pz_Name, pOD->optArg.argString);
+        pz_indent = "";
     }
-}
 
+    if (pOD->fOptState & OPTST_SCALED_NUM)
+        fprintf(option_usage_fp, zRangeScaled, pz_indent);
+
+    fprintf(option_usage_fp, (rng_ct > 1) ? zRangeLie : zRangeOnly, pz_indent);
+    pz_indent = (pOpts != OPTPROC_EMIT_USAGE) ? onetab : deepin;
+
+    for (;;) {
+        if (rng->rmax == LONG_MIN)
+            fprintf(option_usage_fp, zRangeExact, pz_indent, rng->rmin);
+        else if (rng->rmin == LONG_MIN)
+            fprintf(option_usage_fp, zRangeUpto, pz_indent, rng->rmax);
+        else if (rng->rmax == LONG_MAX)
+            fprintf(option_usage_fp, zRangeAbove, pz_indent, rng->rmin);
+        else
+            fprintf(option_usage_fp, zRange, pz_indent, rng->rmin,
+                    rng->rmax);
+
+        if  (--rng_ct <= 0) {
+            fputc('\n', option_usage_fp);
+            break;
+        }
+        fputs(zRangeOr, option_usage_fp);
+        rng++;
+    }
+
+    if (pOpts > OPTPROC_EMIT_LIMIT)
+        pOpts->pUsageProc(pOpts, EXIT_FAILURE);
+}
 
 /*=export_func  optionNumericVal
  * private:
