@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Tue Sep  7 17:54:30 PDT 2010
+ * Generated Fri May  6 07:06:48 PDT 2011
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
 #define AUTOOPTS_PROTO_H_GUARD 1
@@ -21,14 +21,11 @@ ao_malloc(size_t sz);
 LOCAL void *
 ao_realloc(void *p, size_t sz);
 
-LOCAL void
-ao_free(void *p);
-
 LOCAL char *
 ao_strdup(char const *str);
 
 LOCAL tSuccess
-handleOption(tOptions* pOpts, tOptState* pOptState);
+handle_opt(tOptions* pOpts, tOptState* pOptState);
 
 LOCAL tSuccess
 longOptionFind(tOptions* pOpts, char* pzOptName, tOptState* pOptState);
@@ -108,6 +105,12 @@ optionSort(tOptions* pOpts);
 LOCAL void
 addArgListEntry(void** ppAL, void* entry);
 
+/*
+ *  Extracted from usage.c
+ */
+LOCAL void
+set_usage_flags(tOptions * opts, char const * flg_txt);
+
 #ifdef REDEF_LOCAL
 #  undef LOCAL
 #  define LOCAL
